@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875a.  */
+/* A Bison parser, made by GNU Bison 1.875d.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -312,18 +312,25 @@ typedef union YYSTYPE {
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
+# ifndef YYFREE
+#  define YYFREE free
+# endif
+# ifndef YYMALLOC
+#  define YYMALLOC malloc
+# endif
+
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# if YYSTACK_USE_ALLOCA
-#  define YYSTACK_ALLOC alloca
+# ifdef YYSTACK_USE_ALLOCA
+#  if YYSTACK_USE_ALLOCA
+#   define YYSTACK_ALLOC alloca
+#  endif
 # else
-#  ifndef YYSTACK_USE_ALLOCA
-#   if defined (alloca) || defined (_ALLOCA_H)
-#    define YYSTACK_ALLOC alloca
-#   else
-#    ifdef __GNUC__
-#     define YYSTACK_ALLOC __builtin_alloca
-#    endif
+#  if defined (alloca) || defined (_ALLOCA_H)
+#   define YYSTACK_ALLOC alloca
+#  else
+#   ifdef __GNUC__
+#    define YYSTACK_ALLOC __builtin_alloca
 #   endif
 #  endif
 # endif
@@ -336,20 +343,20 @@ typedef union YYSTYPE {
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
+#  define YYSTACK_ALLOC YYMALLOC
+#  define YYSTACK_FREE YYFREE
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYSTYPE_IS_TRIVIAL)))
+	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short yyss;
+  short int yyss;
   YYSTYPE yyvs;
   };
 
@@ -359,13 +366,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if 1 < __GNUC__
+#  if defined (__GNUC__) && 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -401,7 +408,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short yysigned_char;
+   typedef short int yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -485,12 +492,12 @@ static const yysigned_char yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const unsigned short yyrline[] =
+static const unsigned short int yyrline[] =
 {
        0,   222,   222,   231,   240,   247,   273,   299,   306,   320,
-     326,   332,   344,   392,   410,   416,   429,   429,   445,   445,
-     458,   465,   474,   480,   490,   497,   505,   511,   518,   531,
-     536,   545,   557,   562
+     326,   332,   344,   393,   411,   417,   430,   430,   446,   446,
+     459,   466,   475,   481,   491,   498,   506,   512,   519,   532,
+     537,   546,   558,   563
 };
 #endif
 
@@ -499,10 +506,10 @@ static const unsigned short yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "end_of_file", "L_NAME", "L_DIGIT", 
-  "L_COMMAND", "L_BODY", "L_SPACE", "L_UBSPACE", "'@'", "'{'", "'}'", 
-  "'('", "')'", "','", "'='", "'#'", "'\"'", "$accept", "entry", "values", 
-  "value", "content", "content_brace", "@1", "content_quote", "@2", 
+  "$end", "error", "$undefined", "end_of_file", "L_NAME", "L_DIGIT",
+  "L_COMMAND", "L_BODY", "L_SPACE", "L_UBSPACE", "'@'", "'{'", "'}'",
+  "'('", "')'", "','", "'='", "'#'", "'\"'", "$accept", "entry", "values",
+  "value", "content", "content_brace", "@1", "content_quote", "@2",
   "simple_content", "text_part", "text_brace", "text_quote", 0
 };
 #endif
@@ -510,7 +517,7 @@ static const char *const yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short yytoknum[] =
+static const unsigned short int yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
       64,   123,   125,    40,    41,    44,    61,    35,    34
@@ -635,7 +642,7 @@ static const unsigned char yystos[] =
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		goto yyerrlab1
+#define YYERROR		goto yyerrorlab
 
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
@@ -670,11 +677,11 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
-  Current.first_line   = Rhs[1].first_line;      \
-  Current.first_column = Rhs[1].first_column;    \
-  Current.last_line    = Rhs[N].last_line;       \
-  Current.last_column  = Rhs[N].last_column;
+# define YYLLOC_DEFAULT(Current, Rhs, N)		\
+   ((Current).first_line   = (Rhs)[1].first_line,	\
+    (Current).first_column = (Rhs)[1].first_column,	\
+    (Current).last_line    = (Rhs)[N].last_line,	\
+    (Current).last_column  = (Rhs)[N].last_column)
 #endif
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
@@ -718,17 +725,17 @@ do {								\
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
+| TOP (included).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short *bottom, short *top)
+yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -758,9 +765,9 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylineno = yyrline[yyrule];
+  unsigned int yylno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylineno);
+             yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
@@ -797,7 +804,7 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if YYMAXDEPTH == 0
+#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
 # undef YYMAXDEPTH
 #endif
 
@@ -995,9 +1002,9 @@ yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	yyssa[YYINITDEPTH];
-  short *yyss = yyssa;
-  register short *yyssp;
+  short int yyssa[YYINITDEPTH];
+  short int *yyss = yyssa;
+  register short int *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -1034,6 +1041,7 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
+
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1059,7 +1067,7 @@ yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
@@ -1087,7 +1095,7 @@ yyparse ()
 	yystacksize = YYMAXDEPTH;
 
       {
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1376,6 +1384,7 @@ yyreduce:
 	    type = BIBTEX_DATE;
 	    break;
 	}
+
     } 
     while (0);
 
@@ -1388,12 +1397,12 @@ yyreduce:
     break;
 
   case 13:
-#line 394 "bibparse.y"
+#line 395 "bibparse.y"
     { 
     entry_start = start_line + entry->length;
 
     if (entry->preamble) {
-	bibtex_parser_start_error ("entry already contains a preamble");
+	bibtex_parser_start_error ("entry already contains a preamble or has an unexpected comma in its key");
 	YYABORT;
     }
 
@@ -1402,26 +1411,26 @@ yyreduce:
     break;
 
   case 14:
-#line 412 "bibparse.y"
+#line 413 "bibparse.y"
     { 
     yyval.body = bibtex_struct_append (yyvsp[-2].body, yyvsp[0].body);
 }
     break;
 
   case 15:
-#line 418 "bibparse.y"
+#line 419 "bibparse.y"
     {
     yyval.body = yyvsp[0].body;
 }
     break;
 
   case 16:
-#line 429 "bibparse.y"
+#line 430 "bibparse.y"
     { bibtex_parser_is_content = TRUE; }
     break;
 
   case 17:
-#line 432 "bibparse.y"
+#line 433 "bibparse.y"
     { 
     bibtex_parser_is_content = FALSE; 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SUB);
@@ -1432,12 +1441,12 @@ yyreduce:
     break;
 
   case 18:
-#line 445 "bibparse.y"
+#line 446 "bibparse.y"
     { bibtex_parser_is_content = TRUE; }
     break;
 
   case 19:
-#line 448 "bibparse.y"
+#line 449 "bibparse.y"
     { 
     bibtex_parser_is_content = FALSE; 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SUB);
@@ -1448,7 +1457,7 @@ yyreduce:
     break;
 
   case 20:
-#line 460 "bibparse.y"
+#line 461 "bibparse.y"
     { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup (yyvsp[0].text);
@@ -1456,7 +1465,7 @@ yyreduce:
     break;
 
   case 21:
-#line 467 "bibparse.y"
+#line 468 "bibparse.y"
     {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_REF);
     yyval.body->value.ref = g_strdup (yyvsp[0].text);
@@ -1466,21 +1475,21 @@ yyreduce:
     break;
 
   case 22:
-#line 476 "bibparse.y"
+#line 477 "bibparse.y"
     { 
     yyval.body = yyvsp[0].body;
 }
     break;
 
   case 23:
-#line 482 "bibparse.y"
+#line 483 "bibparse.y"
     { 
     yyval.body = yyvsp[0].body;
 }
     break;
 
   case 24:
-#line 492 "bibparse.y"
+#line 493 "bibparse.y"
     { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_COMMAND);
     yyval.body->value.com = g_strdup (yyvsp[0].text + 1);
@@ -1488,7 +1497,7 @@ yyreduce:
     break;
 
   case 25:
-#line 499 "bibparse.y"
+#line 500 "bibparse.y"
     { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SUB);
     yyval.body->value.sub->encloser = BIBTEX_ENCLOSER_BRACE;
@@ -1497,14 +1506,14 @@ yyreduce:
     break;
 
   case 26:
-#line 507 "bibparse.y"
+#line 508 "bibparse.y"
     {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SPACE);
 }
     break;
 
   case 27:
-#line 513 "bibparse.y"
+#line 514 "bibparse.y"
     {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SPACE);
     yyval.body->value.unbreakable = TRUE;
@@ -1512,7 +1521,7 @@ yyreduce:
     break;
 
   case 28:
-#line 520 "bibparse.y"
+#line 521 "bibparse.y"
     {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup (yyvsp[0].text);
@@ -1520,7 +1529,7 @@ yyreduce:
     break;
 
   case 29:
-#line 531 "bibparse.y"
+#line 532 "bibparse.y"
     { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup ("");
@@ -1528,7 +1537,7 @@ yyreduce:
     break;
 
   case 30:
-#line 538 "bibparse.y"
+#line 539 "bibparse.y"
     { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup ("\"");
@@ -1538,14 +1547,14 @@ yyreduce:
     break;
 
   case 31:
-#line 547 "bibparse.y"
+#line 548 "bibparse.y"
     { 
     yyval.body = bibtex_struct_append (yyvsp[-1].body, yyvsp[0].body);
 }
     break;
 
   case 32:
-#line 557 "bibparse.y"
+#line 558 "bibparse.y"
     { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup ("");
@@ -1553,7 +1562,7 @@ yyreduce:
     break;
 
   case 33:
-#line 564 "bibparse.y"
+#line 565 "bibparse.y"
     { 
     yyval.body = bibtex_struct_append (yyvsp[-1].body, yyvsp[0].body);
 }
@@ -1562,8 +1571,8 @@ yyreduce:
 
     }
 
-/* Line 999 of yacc.c.  */
-#line 1567 "y.tab.c"
+/* Line 1010 of yacc.c.  */
+#line 1576 "y.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1604,18 +1613,33 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
+	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx, yycount;
+	  int yyx;
 
-	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (yyx = yyn < 0 ? -yyn : 0;
-	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
+	  int yyxbegin = yyn < 0 ? -yyn : 0;
+
+	  /* Stay within bounds of both yycheck and yytname.  */
+	  int yychecklim = YYLAST - yyn;
+	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
+	  int yycount = 0;
+
+	  yyprefix = ", expecting ";
+	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
-	  yysize += yystrlen ("syntax error, unexpected ") + 1;
-	  yysize += yystrlen (yytname[yytype]);
+	      {
+		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
+		yycount += 1;
+		if (yycount == 5)
+		  {
+		    yysize = 0;
+		    break;
+		  }
+	      }
+	  yysize += (sizeof ("syntax error, unexpected ")
+		     + yystrlen (yytname[yytype]));
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
@@ -1624,16 +1648,13 @@ yyerrlab:
 
 	      if (yycount < 5)
 		{
-		  yycount = 0;
-		  for (yyx = yyn < 0 ? -yyn : 0;
-		       yyx < (int) (sizeof (yytname) / sizeof (char *));
-		       yyx++)
+		  yyprefix = ", expecting ";
+		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			const char *yyq = ! yycount ? ", expecting " : " or ";
-			yyp = yystpcpy (yyp, yyq);
+			yyp = yystpcpy (yyp, yyprefix);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yycount++;
+			yyprefix = " or ";
 		      }
 		}
 	      yyerror (yymsg);
@@ -1654,25 +1675,27 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      /* Return failure if at end of input.  */
-      if (yychar == YYEOF)
+      if (yychar <= YYEOF)
         {
-	  /* Pop the error token.  */
-          YYPOPSTACK;
-	  /* Pop the rest of the stack.  */
-	  while (yyss < yyssp)
-	    {
-	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-	      yydestruct (yystos[*yyssp], yyvsp);
-	      YYPOPSTACK;
-	    }
-	  YYABORT;
+          /* If at end of input, pop the error token,
+	     then the rest of the stack, then return failure.  */
+	  if (yychar == YYEOF)
+	     for (;;)
+	       {
+		 YYPOPSTACK;
+		 if (yyssp == yyss)
+		   YYABORT;
+		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct (yystos[*yyssp], yyvsp);
+	       }
         }
+      else
+	{
+	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+	  yydestruct (yytoken, &yylval);
+	  yychar = YYEMPTY;
 
-      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-      yydestruct (yytoken, &yylval);
-      yychar = YYEMPTY;
-
+	}
     }
 
   /* Else will try to reuse lookahead token after shifting the error
@@ -1680,9 +1703,27 @@ yyerrlab:
   goto yyerrlab1;
 
 
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
+/*---------------------------------------------------.
+| yyerrorlab -- error raised explicitly by YYERROR.  |
+`---------------------------------------------------*/
+yyerrorlab:
+
+#ifdef __GNUC__
+  /* Pacify GCC when the user code never invokes YYERROR and the label
+     yyerrorlab therefore never appears in user code.  */
+  if (0)
+     goto yyerrorlab;
+#endif
+
+  yyvsp -= yylen;
+  yyssp -= yylen;
+  yystate = *yyssp;
+  goto yyerrlab1;
+
+
+/*-------------------------------------------------------------.
+| yyerrlab1 -- common code for both syntax error and YYERROR.  |
+`-------------------------------------------------------------*/
 yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
@@ -1706,9 +1747,8 @@ yyerrlab1:
 
       YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
       yydestruct (yystos[yystate], yyvsp);
-      yyvsp--;
-      yystate = *--yyssp;
-
+      YYPOPSTACK;
+      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
@@ -1757,7 +1797,7 @@ yyreturn:
 }
 
 
-#line 571 "bibparse.y"
+#line 572 "bibparse.y"
      
 	
 
